(deftimelimiter name)(deftimelimiter name config)Define a time limiter under name.
Please refer to time-limiter-config for allowed key value pairs
within the time limiter configuration.
Define a time limiter under `name`. Please refer to `time-limiter-config` for allowed key value pairs within the time limiter configuration.
(time-limiter)(time-limiter config)Create a time limiter with a default or custom time limiter configuration.
Please refer to time-limiter-config for allowed key value pairs
within the time limiter configuration.
Create a time limiter with a default or custom time limiter configuration. Please refer to `time-limiter-config` for allowed key value pairs within the time limiter configuration.
(time-limiter-config opts)Create a TimeLimiterConfig.
Allowed options are:
:timeout-millis Configures the thread execution timeout. Default value is 1 second.
:cancel-running-future? Configures whether cancel is called on the running future. Defaults to true.
Create a TimeLimiterConfig. Allowed options are: * :timeout-millis Configures the thread execution timeout. Default value is 1 second. * :cancel-running-future? Configures whether cancel is called on the running future. Defaults to true.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |